@@ -1,5 +1,3 @@
-{-# LANGUAGE BangPatterns #-}
-
 -- | The inline module provides a limited interface to changing the
 -- style of terminal output. The intention is for this interface to be
 -- used inline with other output systems.
@@ -85,8 +83,8 @@ removeStyle :: Style -> InlineM ()
 removeStyle sMask = modify $ \s ->
     s { inlineAttr =
           let style' = case attrStyle (inlineAttr s) of
-                Default -> error $ "Graphics.Vty.Inline: Cannot removeStyle if applyStyle never used."
-                KeepCurrent -> error $ "Graphics.Vty.Inline: Cannot removeStyle if applyStyle never used."
+                Default -> error "Graphics.Vty.Inline: Cannot removeStyle if applyStyle never used."
+                KeepCurrent -> error "Graphics.Vty.Inline: Cannot removeStyle if applyStyle never used."
                 SetTo st -> st .&. complement sMask
           in (inlineAttr s) { attrStyle = SetTo style' }
       }
