@@ -1,16 +1,9 @@
-{-# LANGUAGE CPP #-}
 {-# OPTIONS_HADDOCK hide #-}
 
-#ifndef MIN_VERSION_base
-#defined MIN_VERSION_base(x,y,z) 1
-#endif
-
 module Graphics.Vty.Inline.Unsafe where
 
 import Graphics.Vty
 
-import Data.Default
-import Data.Monoid
 import Data.IORef
 
 import GHC.IO.Handle (hDuplicate)
@@ -21,10 +14,6 @@ import System.IO.Unsafe
 
 import System.Posix.IO (handleToFd)
 
-#if !(MIN_VERSION_base(4,8,0))
-import Control.Applicative
-#endif
-
 globalVty :: IORef (Maybe Vty)
 {-# NOINLINE globalVty #-}
 globalVty = unsafePerformIO $ newIORef Nothing
@@ -39,10 +28,11 @@ mkDupeConfig = do
     hSetBuffering stdin NoBuffering
     stdinDupe <- hDuplicate stdin >>= handleToFd
     stdoutDupe <- hDuplicate stdout >>= handleToFd
-    return $ def { inputFd = Just stdinDupe, outputFd = Just stdoutDupe }
+    return $ defaultConfig { inputFd = Just stdinDupe, outputFd = Just stdoutDupe }
 
--- | This will create a Vty instance using 'mkVty' and execute an IO action provided that instance.
--- The created Vty instance will be stored to the unsafe 'IORef' 'globalVty'.
+-- | This will create a Vty instance using 'mkVty' and execute an IO
+-- action provided that instance. The created Vty instance will be
+-- stored to the unsafe 'IORef' 'globalVty'.
 --
 -- This instance will use duplicates of the stdin and stdout Handles.
 withVty :: (Vty -> IO b) -> IO b
