@@ -17,6 +17,7 @@ import Blaze.ByteString.Builder.Word (writeWord8)
 
 import Control.Monad (void, when)
 import Control.Monad.Trans
+import Data.Char (toLower)
 import Data.IORef
 
 import System.Posix.IO (fdWrite)
@@ -92,9 +93,9 @@ reserveTerminal variant outFd = liftIO $ do
 utf8Active :: IO Bool
 utf8Active = do
     let vars = ["LC_ALL", "LANG", "LC_CTYPE"]
-    results <- catMaybes <$> mapM getEnv vars
-    let matches = filter ("UTF8" `isInfixOf`) results <>
-                  filter ("UTF-8" `isInfixOf`) results
+    results <- map (toLower <$>) . catMaybes <$> mapM getEnv vars
+    let matches = filter ("utf8" `isInfixOf`) results <>
+                  filter ("utf-8" `isInfixOf`) results
     return $ not $ null matches
 
 -- | Enable bracketed paste mode:
@@ -113,9 +114,6 @@ setUtf8CharSet, setDefaultCharSet :: String
 setUtf8CharSet = "\ESC%G"
 setDefaultCharSet = "\ESC%@"
 
--- | I think xterm is broken: Reseting the background color as the first
--- bytes serialized on a new line does not effect the background color
--- xterm uses to clear the line. Which is used *after* the next newline.
 xtermInlineHack :: Output -> IO ()
 xtermInlineHack t = do
     let writeReset = foldMap (writeWord8.toEnum.fromEnum) "\ESC[K"
