@@ -1,7 +1,8 @@
-module Verify.Data.Terminfo.Parse ( module Verify.Data.Terminfo.Parse
-                                  , module Data.Terminfo.Parse
-                                  )
-    where
+module Verify.Data.Terminfo.Parse
+  ( module Verify.Data.Terminfo.Parse
+  , module Data.Terminfo.Parse
+  )
+where
 
 import Data.Terminfo.Parse
 import Data.Terminfo.Eval
@@ -19,22 +20,22 @@ data NonParamCapString = NonParamCapString String
     deriving Show
 
 instance Arbitrary NonParamCapString where
-    arbitrary 
+    arbitrary
         = ( do
             s <- listOf1 $ (choose (0, 255) >>= return . toEnum) `suchThat` (/= '%')
             return $ NonParamCapString s
-          ) `suchThat` ( \(NonParamCapString str) -> length str < 255 ) 
+          ) `suchThat` ( \(NonParamCapString str) -> length str < 255 )
 
 data LiteralPercentCap = LiteralPercentCap String [Word8]
     deriving ( Show )
 
 instance Arbitrary LiteralPercentCap where
-    arbitrary 
+    arbitrary
         = ( do
             NonParamCapString s <- arbitrary
             (s', bytes) <- insertEscapeOp "%" [toEnum $ fromEnum '%'] s
             return $ LiteralPercentCap s' bytes
-          ) `suchThat` ( \(LiteralPercentCap str _) -> length str < 255 ) 
+          ) `suchThat` ( \(LiteralPercentCap str _) -> length str < 255 )
 
 data IncFirstTwoCap = IncFirstTwoCap String [Word8]
     deriving ( Show )
@@ -45,7 +46,7 @@ instance Arbitrary IncFirstTwoCap where
             NonParamCapString s <- arbitrary
             (s', bytes) <- insertEscapeOp "i" [] s
             return $ IncFirstTwoCap s' bytes
-          ) `suchThat` ( \(IncFirstTwoCap str _) -> length str < 255 ) 
+          ) `suchThat` ( \(IncFirstTwoCap str _) -> length str < 255 )
 
 data PushParamCap = PushParamCap String Int [Word8]
     deriving ( Show )
@@ -57,7 +58,7 @@ instance Arbitrary PushParamCap where
             n <- choose (1,9)
             (s', bytes) <- insertEscapeOp ("p" ++ show n) [] s
             return $ PushParamCap s' n bytes
-          ) `suchThat` ( \(PushParamCap str _ _) -> length str < 255 ) 
+          ) `suchThat` ( \(PushParamCap str _ _) -> length str < 255 )
 
 data DecPrintCap = DecPrintCap String Int [Word8]
     deriving ( Show )
@@ -69,7 +70,7 @@ instance Arbitrary DecPrintCap where
             n <- choose (1,9)
             (s', bytes) <- insertEscapeOp ("p" ++ show n ++ "%d") [] s
             return $ DecPrintCap s' n bytes
-          ) `suchThat` ( \(DecPrintCap str _ _) -> length str < 255 ) 
+          ) `suchThat` ( \(DecPrintCap str _ _) -> length str < 255 )
 
 insertEscapeOp opStr replBytes s = do
     insertPoints <- listOf1 $ elements [0 .. length s - 1]
@@ -92,21 +93,20 @@ bytesForRange cap offset count
     = Vector.toList $ Vector.take count $ Vector.drop offset $ capBytes cap
 
 collectBytes :: CapExpression -> [Word8]
-collectBytes e = concat [ bytes 
+collectBytes e = concat [ bytes
                         | Bytes offset count <- capOps e
                         , let bytes = bytesForRange e offset count
                         ]
-    
+
 
 verifyBytesEqual :: [Word8] -> [Word8] -> Result
-verifyBytesEqual outBytes expectedBytes 
+verifyBytesEqual outBytes expectedBytes
     = if outBytes == expectedBytes
         then succeeded
-        else failed 
-             { reason = "outBytes [" 
+        else failed
+             { reason = "outBytes ["
                       ++ hexDump outBytes
                       ++ "] /= expectedBytes ["
                       ++ hexDump expectedBytes
                       ++ "]"
              }
-
