@@ -1,10 +1,8 @@
-module Verify.Graphics.Vty.Prelude ( module Verify.Graphics.Vty.Prelude
-                                   , module Graphics.Vty.Prelude
-                                   , MockWindow(..)
-                                   )
-    where
-
-import Graphics.Vty.Prelude
+module Verify.Graphics.Vty.Prelude
+  ( module Verify.Graphics.Vty.Prelude
+  , MockWindow(..)
+  )
+where
 
 import Graphics.Vty.Debug
 
