@@ -3,7 +3,7 @@
 module VerifyEvalTerminfoCaps where
 
 import Blaze.ByteString.Builder.Internal.Write (runWrite, getBound)
-import Data.Terminfo.Eval 
+import Data.Terminfo.Eval
 import Data.Terminfo.Parse
 import Control.DeepSeq
 
@@ -24,8 +24,9 @@ import Foreign.Marshal.Alloc (mallocBytes)
 import Foreign.Ptr (Ptr, minusPtr)
 import Numeric
 
--- If a terminal defines one of the caps then it's expected to be parsable.
-capsOfInterest = 
+-- If a terminal defines one of the caps then it's expected to be
+-- parsable.
+capsOfInterest =
     [ "cup"
     , "sc"
     , "rc"
@@ -49,12 +50,13 @@ fromCapname ti name = fromJust $ Terminfo.getCapability ti (Terminfo.tiGetStr na
 
 tests :: IO [Test]
 tests = do
-    evalBuffer :: Ptr Word8 <- mallocBytes (1024 * 1024) -- Should be big enough for any termcaps ;-)
+    -- 1 MB should be big enough for any termcaps ;-)
+    evalBuffer :: Ptr Word8 <- mallocBytes (1024 * 1024)
     fmap concat $ forM terminalsOfInterest $ \termName -> do
         putStrLn $ "adding tests for terminal: " ++ termName
         mti <- try $ Terminfo.setupTerm termName
         case mti of
-            Left (_e :: SomeException) 
+            Left (_e :: SomeException)
                 -> return []
             Right ti -> do
                 fmap concat $ forM capsOfInterest $ \capName -> do
@@ -71,7 +73,7 @@ tests = do
 {-# NOINLINE verifyEvalCap #-}
 verifyEvalCap :: Ptr Word8 -> CapExpression -> Int -> Property
 verifyEvalCap evalBuffer expr !junkInt = do
-    forAll (vector 9) $ \inputValues -> 
+    forAll (vector 9) $ \inputValues ->
         let write = writeCapExpr expr inputValues
             !byteCount = getBound write
         in liftIOResult $ do
@@ -79,12 +81,11 @@ verifyEvalCap evalBuffer expr !junkInt = do
             forM_ [0..100] $ \i -> runWrite write startPtr
             endPtr <- runWrite write startPtr
             case endPtr `minusPtr` startPtr of
-                count | count < 0        -> 
+                count | count < 0        ->
                             return $ failed { reason = "End pointer before start pointer." }
-                      | toEnum count > byteCount -> 
-                            return $ failed { reason = "End pointer past end of buffer by " 
-                                                       ++ show (toEnum count - byteCount) 
+                      | toEnum count > byteCount ->
+                            return $ failed { reason = "End pointer past end of buffer by "
+                                                       ++ show (toEnum count - byteCount)
                                             }
-                      | otherwise        -> 
+                      | otherwise        ->
                             return succeeded
-
